@@ -1,11 +1,11 @@
 #include <iostream>
-#include <experimental/filesystem>
+#include <filesystem>
 
 // explicitly link against stdc++fs:
 //
 //      gx spaceinfo.cc -lstdc++fs
 
-namespace fs = std::experimental::filesystem;
+namespace fs = std::filesystem;
 
 //demo
 int main()
